@@ -2,7 +2,7 @@
 import re
 
 from pptree import Node, print_tree
-from suite_py.lib.handler import aws_handler as aws
+from suite_py.lib.handler.aws_handler import Aws
 from suite_py.lib import logger
 
 
@@ -10,10 +10,11 @@ class IP:
     def __init__(self, project, env):
         self._project = project
         self._env = env
+        self._aws = Aws()
 
     def run(self):
 
-        clusters_names = aws.get_ecs_clusters(self._env)
+        clusters_names = self._aws.get_ecs_clusters(self._env)
         n_services = Node("services")
 
         projects = {"prima": ["web", "consumer-api"], "ab_normal": ["abnormal"]}
@@ -22,7 +23,7 @@ class IP:
         for cluster_name in clusters_names:
 
             services = []
-            all_services = aws.get_ecs_services(cluster_name)
+            all_services = self._aws.get_ecs_services(cluster_name)
 
             for service in all_services:
                 if service["status"] == "ACTIVE":
@@ -32,11 +33,13 @@ class IP:
 
             for service in services:
                 container_instances = []
-                container_instances = aws.get_container_instances_arn_from_service(
-                    cluster_name, service
+                container_instances = (
+                    self._aws.get_container_instances_arn_from_service(
+                        cluster_name, service
+                    )
                 )
                 if container_instances:
-                    ips = aws.get_ips_from_container_instances(
+                    ips = self._aws.get_ips_from_container_instances(
                         cluster_name, container_instances
                     )
 
